# encoding: utf-8

"""Provides Python 2/3 compatibility objects."""

import sys

try:
    from collections.abc import Container, Mapping, Sequence
except ImportError:
    from collections import Container, Mapping, Sequence

if sys.version_info >= (3, 0):
    from .python3 import (  # noqa
        BytesIO,
        Unicode,
        is_integer,
        is_string,
        is_unicode,
        to_unicode,
    )
else:
    from .python2 import (  # noqa
        BytesIO,
        Unicode,
        is_integer,
        is_string,
        is_unicode,
        to_unicode,
    )

__all__ = [
    "BytesIO",
    "Container",
    "Mapping",
    "Sequence",
    "Unicode",
    "is_integer",
    "is_string",
    "is_unicode",
    "to_unicode",
]



print("import: 'pptx'")
import pptx

print("import: 'pptx.chart'")
import pptx.chart

print("import: 'pptx.compat'")
import pptx.compat

print("import: 'pptx.dml'")
import pptx.dml

print("import: 'pptx.enum'")
import pptx.enum

print("import: 'pptx.opc'")
import pptx.opc

print("import: 'pptx.oxml'")
import pptx.oxml

print("import: 'pptx.oxml.chart'")
import pptx.oxml.chart

print("import: 'pptx.oxml.dml'")
import pptx.oxml.dml

print("import: 'pptx.oxml.shapes'")
import pptx.oxml.shapes

print("import: 'pptx.parts'")
import pptx.parts

print("import: 'pptx.shapes'")
import pptx.shapes

print("import: 'pptx.text'")
import pptx.text

